iamai.adapter.gensokyo.gensokyo.message module
==============================================

.. automodule:: iamai.adapter.gensokyo.gensokyo.message
   :members:
   :undoc-members:
   :show-inheritance:
